==> Agi4x44PreProcess_1.2.0.tar.gz: Agi4x44PreProcess/man/ensembl.htmlpage.Rd <==
\name{ensembl.htmlpage}
\alias{ensembl.htmlpage}
\title{ genes.rpt.agi (Internal function) }
\description{
	Internal function to be used by \code{\link{genes.rpt.agi} }
}
\usage{
ensembl.htmlpage(probe.ids, probe.chr, filename, annotation.package, title, othernames, table.head, table.center = TRUE)
}
\arguments{
  \item{probe.ids}{ }
  \item{probe.chr}{  }
  \item{filename}{  }
  \item{annotation.package}{a character specifying the AGI annotation package: 'hgug4112a.db','mgug4122a.db' }
  \item{title}{  }
  \item{othernames}{  }
  \item{table.head}{  }
  \item{table.center}{  }
}
\details{
	It writes an html file with a link to the 
	ENSEMBL data base for each probe in the input. 
}
\value{
	An html file 
}
\author{ Pedro Lopez-Romero }

\seealso{  \code{\link{genes.rpt.agi}} }
\examples{
\dontrun{
        data(dd)
	library(hgug4112a.db)
        PROBE_ID=dd$genes$ProbeName[200:210]
        probe.chr=dd$other$chr_coord[200:210,1]
        GENE_ID = unlist(lookUp(PROBE_ID, "hgug4112a.db", "ACCNUM") )
        gene.sym=lookUp(PROBE_ID,"hgug4112a.db","SYMBOL")
        filename=paste("Gen.Sets","example","html",sep=".")
        title="Replicated Gene"
        head <- c("PROBE ID","ACCNUM","SYMBOL","probe chr coord")

        ensembl.htmlpage(PROBE_ID,probe.chr,filename,"hgug4112a.db",
                                title, table.head=head,table.center = TRUE,
                                other=list(unlist(GENE_ID),unlist(gene.sym),unlist(probe.chr)))

}
}
\keyword{documentation}
\keyword{utilities}

==> Agi4x44PreProcess_1.12.0.tar.gz: Agi4x44PreProcess/man/ensembl.htmlpage.Rd <==
\name{ensembl.htmlpage}
\alias{ensembl.htmlpage}
\title{ genes.rpt.agi (Internal function) }
\description{
	Internal function to be used by \code{\link{genes.rpt.agi} }
}
\usage{
ensembl.htmlpage(probe.ids, probe.chr, filename, annotation.package, title, othernames, table.head, table.center = TRUE)
}
\arguments{
  \item{probe.ids}{internal function - some arguments are not documented}
  \item{probe.chr}{internal function - some arguments are not documented}
  \item{filename}{internal function - some arguments are not documented}
  \item{annotation.package}{a character specifying the AGI annotation package: 'hgug4112a.db','mgug4122a.db' }
  \item{title}{internal function - some arguments are not documented}
  \item{othernames}{internal function - some arguments are not documented}
  \item{table.head}{internal function - some arguments are not documented}
  \item{table.center}{internal function - some arguments are not documented}
}
\details{
	It writes an html file with a link to the 
	ENSEMBL data base for each probe in the input. 
}
\value{
	An html file 
}
\author{ Pedro Lopez-Romero }

\seealso{  \code{\link{genes.rpt.agi}} }
\examples{
\dontrun{
        data(dd)
	library(hgug4112a.db)
        PROBE_ID=dd$genes$ProbeName[200:210]
        probe.chr=dd$other$chr_coord[200:210,1]
        GENE_ID = unlist(lookUp(PROBE_ID, "hgug4112a.db", "ACCNUM") )
        gene.sym=lookUp(PROBE_ID,"hgug4112a.db","SYMBOL")
        filename=paste("Gen.Sets","example","html",sep=".")
        title="Replicated Gene"
        head <- c("PROBE ID","ACCNUM","SYMBOL","probe chr coord")

        ensembl.htmlpage(PROBE_ID,probe.chr,filename,"hgug4112a.db",
                                title, table.head=head,table.center = TRUE,
                                other=list(unlist(GENE_ID),unlist(gene.sym),unlist(probe.chr)))

}
}
\keyword{documentation}
\keyword{utilities}
